# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: traffic_sign.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import commonroad.scenario_definition.protobuf_format.generated_scripts.util_pb2 as util__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='traffic_sign.proto',
  package='commonroad',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12traffic_sign.proto\x12\ncommonroad\x1a\nutil.proto\"\xc7\x39\n\x18TrafficSignIDGermanyEnum\"\xaa\x39\n\x14TrafficSignIDGermany\x12\x17\n\x13WARNING_DANGER_SPOT\x10\x00\x12\x1d\n\x19WARNING_RIGHT_BEFORE_LEFT\x10\x01\x12\x16\n\x12WARNING_LEFT_CURVE\x10\x02\x12\x17\n\x13WARNING_RIGHT_CURVE\x10\x03\x12 \n\x1cWARNING_STEEP_HILL_DOWNWARDS\x10\x04\x12\x19\n\x15WARNING_SLIPPERY_ROAD\x10\x05\x12\x1d\n\x19WARNING_CONSTRUCTION_SITE\x10\x06\x12!\n\x1dWARNING_TRAFFIC_QUEUES_LIKELY\x10\x07\x12\x1c\n\x18WARNING_ONCOMING_TRAFFIC\x10\x08\x12 \n\x1cWARNING_TRAFFIC_LIGHTS_AHEAD\x10\t\x12\x1d\n\x19WARNING_PEDESTRIANS_RIGHT\x10\n\x12\x1c\n\x18WARNING_PEDESTRIANS_LEFT\x10\x0b\x12\x1c\n\x18WARNING_CROSSING_CYCLIST\x10\x0c\x12!\n\x1dWARNING_ANIMAL_CROSSING_RIGHT\x10\r\x12\x18\n\x14WARNING_LOOSE_GRAVEL\x10\x0e\x12\x0b\n\x07RAILWAY\x10\x0f\x12\t\n\x05YIELD\x10\x10\x12\x08\n\x04STOP\x10\x11\x12\x1f\n\x1bPRIORITY_OPPOSITE_DIRECTION\x10\x12\x12\x14\n\x10TURN_RIGHT_AHEAD\x10\x13\x12\x13\n\x0fTURN_LEFT_AHEAD\x10\x14\x12\x17\n\x13KEEP_STRAIGHT_AHEAD\x10\x15\x12\x1e\n\x1aPRESCRIBED_DIRECTION_RIGHT\x10\x16\x12\x0e\n\nROUNDABOUT\x10\x17\x12\x10\n\x0cONEWAY_RIGHT\x10\x18\x12\x0f\n\x0bONEWAY_LEFT\x10\x19\x12\x1b\n\x17PRESCRIBED_PASSING_LEFT\x10\x1a\x12\x1c\n\x18PRESCRIBED_PASSING_RIGHT\x10\x1b\x12!\n\x1d\x44O_NOT_DRIVE_ON_SHOULDER_LANE\x10\x1c\x12(\n$DO_NOT_DRIVE_ON_SHOULDER_LANE_2_LANE\x10\x1d\x12(\n$DO_NOT_DRIVE_ON_SHOULDER_LANE_3_LANE\x10\x1e\x12\x0c\n\x08\x42US_STOP\x10\x1f\x12\x0b\n\x07\x42IKEWAY\x10 \x12\x0c\n\x08SIDEWALK\x10!\x12\x1f\n\x1bPEDESTRIAN_AND_BICYCLE_ROAD\x10\"\x12\x19\n\x15PEDESTRIAN_ZONE_START\x10#\x12\x17\n\x13PEDESTRIAN_ZONE_END\x10$\x12\x16\n\x12\x42ICYCLE_ROAD_START\x10%\x12\x14\n\x10\x42ICYCLE_ROAD_END\x10&\x12\x0b\n\x07\x42USLANE\x10\'\x12\x14\n\x10\x42\x41N_ALL_VEHICLES\x10(\x12\x0c\n\x08\x42\x41N_CARS\x10)\x12\x0e\n\nBAN_TRUCKS\x10*\x12\x0f\n\x0b\x42\x41N_BICYCLE\x10+\x12\x12\n\x0e\x42\x41N_MOTORCYCLE\x10,\x12\x0b\n\x07\x42\x41N_BUS\x10-\x12\x12\n\x0e\x42\x41N_PEDESTRIAN\x10.\x12 \n\x1c\x42\x41N_CAR_TRUCK_BUS_MOTORCYCLE\x10/\x12)\n%BAN_VEHICLES_CARRYING_DANGEROUS_GOODS\x10\x30\x12\x0e\n\nMAX_WEIGHT\x10\x31\x12\r\n\tMAX_WIDTH\x10\x32\x12\x0e\n\nMAX_HEIGHT\x10\x33\x12\x0e\n\nMAX_LENGTH\x10\x34\x12\x0c\n\x08NO_ENTRY\x10\x35\x12\x1c\n\x18\x45NVIRONMENTAL_ZONE_START\x10\x36\x12\x1a\n\x16\x45NVIRONMENTAL_ZONE_END\x10\x37\x12\n\n\x06U_TURN\x10\x38\x12\r\n\tMAX_SPEED\x10\x39\x12\x18\n\x14MAX_SPEED_ZONE_START\x10:\x12\x16\n\x12MAX_SPEED_ZONE_END\x10;\x12\r\n\tMIN_SPEED\x10<\x12\x17\n\x13NO_OVERTAKING_START\x10=\x12\x1e\n\x1aNO_OVERTAKING_TRUCKS_START\x10>\x12\x11\n\rMAX_SPEED_END\x10?\x12\x15\n\x11NO_OVERTAKING_END\x10@\x12\x1c\n\x18NO_OVERTAKING_TRUCKS_END\x10\x41\x12$\n ALL_MAX_SPEED_AND_OVERTAKING_END\x10\x42\x12\x17\n\x13NO_STOP_START_RIGHT\x10\x43\x12\x18\n\x14NO_STOP_CENTER_RIGHT\x10\x44\x12 \n\x1cRESTRICTED_STOP_CENTER_RIGHT\x10\x45\x12\x10\n\x0cRIGHT_OF_WAY\x10\x46\x12\x0c\n\x08PRIORITY\x10G\x12\x1a\n\x16PRIORITY_OVER_ONCOMING\x10H\x12\r\n\tTOWN_SIGN\x10I\x12\x12\n\x0eTOWN_SIGN_BACK\x10J\x12\x10\n\x0cPARKING_AREA\x10K\x12\x15\n\x11PARKING_AREA_LEFT\x10L\x12\x16\n\x12PARKING_AREA_RIGHT\x10M\x12\x1b\n\x17PARKING_AREA_RIGHT_LEFT\x10N\x12\x1d\n\x19TRAFFIC_CALMED_AREA_START\x10O\x12\x1b\n\x17TRAFFIC_CALMED_AREA_END\x10P\x12\n\n\x06TUNNEL\x10Q\x12\x13\n\x0f\x45MERYGECNY_STOP\x10R\x12\x14\n\x10INTERSTATE_START\x10S\x12\x12\n\x0eINTERSTATE_END\x10T\x12\x11\n\rHIGHWAY_START\x10U\x12\x0f\n\x0bHIGHWAY_END\x10V\x12 \n\x1cHIGHWAY_EXIT_WITH_PLACE_NAME\x10W\x12\x0e\n\nEXIT_ROUTE\x10X\x12\x10\n\x0cHIGHWAY_EXIT\x10Y\x12\x11\n\rEXIT_BUILT_UP\x10Z\x12\x10\n\x0c\x45XIT_GENERAL\x10[\x12\x18\n\x14PEDESTRIANS_CROSSING\x10\\\x12\x19\n\x15WATER_PROTECTION_ZONE\x10]\x12\x16\n\x12TRAFFIC_ASSISTANTS\x10^\x12\x0c\n\x08\x44\x45\x41\x44_END\x10_\x12\n\n\x06POLICE\x10`\x12\x1a\n\x16\x45MERGENCY_CALL_STATION\x10\x61\x12\x0f\n\x0bGAS_STATION\x10\x62\x12\x19\n\x15\x43\x41MP_AND_CARAVAN_SITE\x10\x63\x12\x14\n\x10\x41TTRACTION_POINT\x10\x64\x12\x13\n\x0fTOURISTIC_ROUTE\x10\x65\x12\x1b\n\x17NEARBY_ATTRACTION_POINT\x10\x66\x12\x18\n\x14HIGHWAY_INTERSECTION\x10g\x12\x1e\n\x1a\x44IRECTION_ARROW_SIGN_MULTI\x10h\x12\x1f\n\x1b\x44IRECTION_ARROW_SIGN_SINGLE\x10i\x12\x1f\n\x1b\x44IRECTION_SIGN_CONSOLIDATED\x10j\x12\x1e\n\x1a\x45XPRESSWAY_ARROW_DIRECTION\x10k\x12*\n&ARROW_SIGN_POST_POINT_OF_INTEREST_LEFT\x10l\x12\x0b\n\x07STATION\x10m\x12\x14\n\x10GUIDE_SIGN_TABLE\x10n\x12\x15\n\x11\x41\x44VANCE_DIRECTION\x10o\x12\x13\n\x0f\x44IRECTIONS_SIGN\x10p\x12\"\n\x1e\x45XPRESSWAY_ENTRANCE_DIRECTIONS\x10q\x12\x1b\n\x17INTERSTATE_ANNOUNCEMENT\x10r\x12 \n\x1cINTERSTATE_ADVANCE_DIRECTION\x10s\x12 \n\x1cHIGHWAY_EXIT_AHEAD_100_METER\x10t\x12 \n\x1cHIGHWAY_EXIT_AHEAD_200_METER\x10u\x12 \n\x1cHIGHWAY_EXIT_AHEAD_300_METER\x10v\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_100_METRES\x10w\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_200_METRES\x10x\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_300_METRES\x10y\x12\x17\n\x13INTERSTATE_DISTANCE\x10z\x12\x11\n\rDETOUR_SKETCH\x10{\x12\x13\n\x0f\x44\x45TOUR_STRAIGHT\x10|\x12\x19\n\x15\x44\x45TOUR_ON_DEMAND_LEFT\x10}\x12%\n!DETOUR_ON_DEMAND_GET_IN_LEFT_LANE\x10~\x12\'\n#DETOUR_ON_DEMAND_ANNOUNCEMENT_RIGHT\x10\x7f\x12\x1b\n\x16\x44\x45TOUR_ON_DEMAND_RIGHT\x10\x80\x01\x12\'\n\"DETOUR_ON_DEMAND_GET_IN_RIGHT_LANE\x10\x81\x01\x12%\n DETOUR_ON_DEMAND_STRAIGHTFORWARD\x10\x82\x01\x12%\n TRANSITION_3_LEFT_2_TRANSITIONED\x10\x83\x01\x12!\n\x1cTRANSITION_1_LEFT_1_STRAIGHT\x10\x84\x01\x12\x17\n\x12TRANSITION_3_RIGHT\x10\x85\x01\x12%\n LANE_BOARD_NO_OPPOSITE_TWO_LANES\x10\x86\x01\x12\"\n\x1dTHREE_LANES_NO_ONCOMING_LANES\x10\x87\x01\x12!\n\x1c\x46OUR_LANES_NO_ONCOMING_LANES\x10\x88\x01\x12!\n\x1c\x46IVE_LANES_NO_ONCOMING_LANES\x10\x89\x01\x12.\n)LANE_BOARD_3_LANES_NO_OPPOSITE_WITH_SIGNS\x10\x8a\x01\x12&\n!NARROWING_LANES_1_LANE_FROM_RIGHT\x10\x8b\x01\x12%\n NARROWING_LANES_1_LANE_FROM_LEFT\x10\x8c\x01\x12(\n#NARROWING_LANES_2_LANES_PLUS_1_LEFT\x10\x8d\x01\x12>\n9FOUR_LANES_NO_ONCOMING_TRAFFIC_TWO_RIGHT_LANES_TURN_RIGHT\x10\x8e\x01\x12+\n&MERGING_LANES_1_LANE_PLUS_1_LANE_RIGHT\x10\x8f\x01\x12\x0c\n\x07\x42\x41RRIER\x10\x90\x01\x12\x19\n\x14\x42\x41RRIER_GATE_100_800\x10\x91\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_100_1200\x10\x92\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_100_1600\x10\x93\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_250_1600\x10\x94\x01\x12\x11\n\x0c\x42\x41RRIER_GATE\x10\x95\x01\x12+\n&ROAD_WARNING_POST_SCRAPER_BEACON_RIGHT\x10\x96\x01\x12)\n$ROAD_WARNING_POST_ARROW_BEACON_RIGHT\x10\x97\x01\x12*\n%ROAD_WARNING_POST_SCRAPER_BEACON_LEFT\x10\x98\x01\x12\x31\n,ROAD_WARNING_POST_SCRAPER_BEACON_ARROW_RIGHT\x10\x99\x01\x12,\n\'ROAD_WARNING_POST_GUIDE_UP_THREE_ARROWS\x10\x9a\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_LEFT_SINGLE\x10\x9b\x01\x12\x1e\n\x19\x44IRECTION_SIGN_LEFT_SMALL\x10\x9c\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_LEFT_MEDIUM\x10\x9d\x01\x12\x1e\n\x19\x44IRECTION_SIGN_LEFT_LARGE\x10\x9e\x01\x12 \n\x1b\x44IRECTION_SIGN_RIGHT_SINGLE\x10\x9f\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_RIGHT_SMALL\x10\xa0\x01\x12 \n\x1b\x44IRECTION_SIGN_RIGHT_MEDIUM\x10\xa1\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_RIGHT_LARGE\x10\xa2\x01\x12\x18\n\x13WARNING_PANEL_RIGHT\x10\xa3\x01\x12\x17\n\x12WARNING_PANEL_LEFT\x10\xa4\x01\x12!\n\x1cWARNING_PANEL_STRAIGHT_BROAD\x10\xa5\x01\x12 \n\x1bWARNING_PANEL_STRAIGHT_HIGH\x10\xa6\x01\x12\'\n\"GUIDE_SILL_WITH_GUIDE_BEACON_RIGHT\x10\xa7\x01\x12\'\n\"GUIDE_RAIL_WITH_GUIDE_BEACON_RIGHT\x10\xa8\x01\x12(\n#GUIDE_PANEL_WITH_GUIDE_BEACON_RIGHT\x10\xa9\x01\x12\x10\n\x0bGREEN_ARROW\x10\xaa\x01\x12\x1c\n\x17\x41\x44\x44ITION_LEFT_DIRECTION\x10\xab\x01\x12\x1e\n\x19\x41\x44\x44ITION_LEFT_DIRECTION_1\x10\xac\x01\x12)\n$ADDITION_LEFT_DIRECTION_DANGER_POINT\x10\xad\x01\x12\x1f\n\x1a\x41\x44\x44ITION_RIGHT_DIRECTION_1\x10\xae\x01\x12*\n%ADDITION_RIGHT_DIRECTION_DANGER_POINT\x10\xaf\x01\x12(\n#ADDITION_BOTH_DIRECTIONS_HORIZONTAL\x10\xb0\x01\x12&\n!ADDITION_BOTH_DIRECTIONS_VERTICAL\x10\xb1\x01\x12 \n\x1b\x41\x44\x44ITION_VALID_FOR_X_METERS\x10\xb2\x01\x12$\n\x1f\x41\x44\x44ITION_VALID_FOR_X_KILOMETERS\x10\xb3\x01\x12=\n8ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_RIGHT_YIELD\x10\xb4\x01\x12=\n8ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_RIGHT_YIELD\x10\xb5\x01\x12\x37\n2ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD\x10\xb6\x01\x12\x34\n/ADDITION_LEFT_TURNING_PRIORITY_WITH_RIGHT_YIELD\x10\xb7\x01\x12\x37\n2ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD\x10\xb8\x01\x12=\n8ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_LEFT_YIELD\x10\xb9\x01\x12=\n8ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_LEFT_YIELD\x10\xba\x01\x12\x38\n3ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD\x10\xbb\x01\x12\x34\n/ADDITION_RIGHT_TURNING_PRIORITY_WITH_LEFT_YIELD\x10\xbc\x01\x12\x38\n3ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD\x10\xbd\x01\x12\x1f\n\x1a\x41\x44\x44ITION_VALID_IN_X_METERS\x10\xbe\x01\x12#\n\x1e\x41\x44\x44ITION_VALID_IN_X_KILOMETERS\x10\xbf\x01\x12%\n ADDITION_VALID_IN_200_KILOMETERS\x10\xc0\x01\x12!\n\x1c\x41\x44\x44ITION_VALID_IN_400_METRES\x10\xc1\x01\x12!\n\x1c\x41\x44\x44ITION_VALID_IN_600_METRES\x10\xc2\x01\x12#\n\x1e\x41\x44\x44ITION_VALID_IN_2_KILOMETERS\x10\xc3\x01\x12\x19\n\x14\x41\x44\x44ITION_OIL_ON_ROAD\x10\xc4\x01\x12\x13\n\x0e\x41\x44\x44ITION_SMOKE\x10\xc5\x01\x12\x1a\n\x15\x41\x44\x44ITION_LOOSE_GRAVEL\x10\xc6\x01\x12 \n\x1b\x41\x44\x44ITION_BUILDING_SITE_EXIT\x10\xc7\x01\x12\x1a\n\x15\x41\x44\x44ITION_DAMAGED_ROAD\x10\xc9\x01\x12\x18\n\x13\x41\x44\x44ITION_DIRTY_ROAD\x10\xca\x01\x12!\n\x1c\x41\x44\x44ITION_DANGER_OF_COLLISION\x10\xcb\x01\x12\x1c\n\x17\x41\x44\x44ITION_TOAD_MIGRATION\x10\xcc\x01\x12\"\n\x1d\x41\x44\x44ITION_DANGER_OF_CONGESTION\x10\xcd\x01\x12*\n%ADDITION_RESTRICTED_VIEW_DUE_TO_TREES\x10\xce\x01\x12\x1c\n\x17\x44\x41NGER_INDICATION_SMOKE\x10\xcf\x01\x12&\n!ADDITION_CHILDREN_PLAYING_ON_ROAD\x10\xd0\x01\x12#\n\x1e\x41\x44\x44ITION_WINTER_SPORTS_ALLOWED\x10\xd1\x01\x12\x38\n3ADDITION_TRAILERS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS\x10\xd2\x01\x12\x38\n3ADDITION_CARAVANS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS\x10\xd3\x01\x12\x1d\n\x18\x41\x44\x44ITION_ROLLING_HIGHWAY\x10\xd4\x01\x12\x1a\n\x15\x41\x44\x44ITION_LOADING_AREA\x10\xd5\x01\x12\x11\n\x0c\x41\x44\x44ITION_END\x10\xd6\x01\x12\x1e\n\x19\x41\x44\x44ITION_GET_OFF_BICYCLES\x10\xd7\x01\x12\x17\n\x12\x41\x44\x44ITION_NO_MOPEDS\x10\xd8\x01\x12 \n\x1b\x41\x44\x44ITION_GREEN_WAVE_AT_KM_H\x10\xd9\x01\x12\x1e\n\x19\x41\x44\x44ITION_STOP_HERE_AT_RED\x10\xda\x01\x12\x1b\n\x16\x41\x44\x44ITION_NOISE_CONTROL\x10\xdb\x01\x12\x1f\n\x1a\x41\x44\x44ITION_INFLOW_REGULATION\x10\xdc\x01\x12\x1c\n\x17\x41\x44\x44ITION_SECONDARY_LANE\x10\xdd\x01\x12\x14\n\x0f\x41\x44\x44ITION_SCHOOL\x10\xde\x01\x12\x1a\n\x15\x41\x44\x44ITION_KINDERGARTEN\x10\xdf\x01\x12\x1d\n\x18\x41\x44\x44ITION_RETIREMENT_HOME\x10\xe0\x01\x12\x16\n\x11\x41\x44\x44ITION_HOSPITAL\x10\xe1\x01\x12!\n\x1c\x41\x44\x44ITION_RESIDENTS_PERMITTED\x10\xe2\x01\x12 \n\x1b\x41\x44\x44ITION_BICYCLES_PERMITTED\x10\xe3\x01\x12\x1c\n\x17\x41\x44\x44ITION_CARS_PERMITTED\x10\xe4\x01\x12#\n\x1e\x41\x44\x44ITION_AGRICULTURE_PERMITTED\x10\xe5\x01\x12\x1e\n\x19\x41\x44\x44ITION_FOREST_PERMITTED\x10\xe6\x01\x12*\n%ADDITION_AGRICULTURE_FOREST_PERMITTED\x10\xe7\x01\x12%\n ADDITION_GREEN_STICKER_PERMITTED\x10\xe8\x01\x12#\n\x1e\x41\x44\x44ITION_TIME_PERIOD_PERMITTED\x10\xe9\x01\x12\x32\n-ADDITION_MOTOR_VEHICLES_ALLOWED_MASS_3_5_TONS\x10\xea\x01\x12\x1f\n\x1a\x41\x44\x44ITION_MIN_MASS_3_5_TONS\x10\xeb\x01\x12(\n#ADDITION_NO_WATER_POLLUTANTS_LOADED\x10\xec\x01\x12\x1a\n\x15\x41LLOWED_MASS_7_5_TONS\x10\xed\x01\x12\x1f\n\x1a\x41\x44\x44ITION_VALID_ON_SHOULDER\x10\xee\x01\x12\x1c\n\x17\x41\x44\x44ITION_VALID_WHEN_WET\x10\xef\x01\x12\x19\n\x14LINE_MARKING_MISSING\x10\xf0\x01\x12\x0c\n\x07UNKNOWN\x10\xf1\x01\"\xc6\x39\n\x18TrafficSignIDZamundaEnum\"\xa9\x39\n\x14TrafficSignIDZamunda\x12\x17\n\x13WARNING_DANGER_SPOT\x10\x00\x12\x1d\n\x19WARNING_RIGHT_BEFORE_LEFT\x10\x01\x12\x16\n\x12WARNING_LEFT_CURVE\x10\x02\x12\x17\n\x13WARNING_RIGHT_CURVE\x10\x03\x12 \n\x1cWARNING_STEEP_HILL_DOWNWARDS\x10\x04\x12\x19\n\x15WARNING_SLIPPERY_ROAD\x10\x05\x12\x1d\n\x19WARNING_CONSTRUCTION_SITE\x10\x06\x12!\n\x1dWARNING_TRAFFIC_QUEUES_LIKELY\x10\x07\x12\x1c\n\x18WARNING_ONCOMING_TRAFFIC\x10\x08\x12 \n\x1cWARNING_TRAFFIC_LIGHTS_AHEAD\x10\t\x12\x1d\n\x19WARNING_PEDESTRIANS_RIGHT\x10\n\x12\x1c\n\x18WARNING_PEDESTRIANS_LEFT\x10\x0b\x12\x1c\n\x18WARNING_CROSSING_CYCLIST\x10\x0c\x12!\n\x1dWARNING_ANIMAL_CROSSING_RIGHT\x10\r\x12\x18\n\x14WARNING_LOOSE_GRAVEL\x10\x0e\x12\x0b\n\x07RAILWAY\x10\x0f\x12\t\n\x05YIELD\x10\x10\x12\x08\n\x04STOP\x10\x11\x12\x1f\n\x1bPRIORITY_OPPOSITE_DIRECTION\x10\x12\x12\x14\n\x10TURN_RIGHT_AHEAD\x10\x13\x12\x13\n\x0fTURN_LEFT_AHEAD\x10\x14\x12\x17\n\x13KEEP_STRAIGHT_AHEAD\x10\x15\x12\x1e\n\x1aPRESCRIBED_DIRECTION_RIGHT\x10\x16\x12\x0e\n\nROUNDABOUT\x10\x17\x12\x10\n\x0cONEWAY_RIGHT\x10\x18\x12\x0f\n\x0bONEWAY_LEFT\x10\x19\x12\x1b\n\x17PRESCRIBED_PASSING_LEFT\x10\x1a\x12\x1c\n\x18PRESCRIBED_PASSING_RIGHT\x10\x1b\x12!\n\x1d\x44O_NOT_DRIVE_ON_SHOULDER_LANE\x10\x1c\x12(\n$DO_NOT_DRIVE_ON_SHOULDER_LANE_2_LANE\x10\x1d\x12(\n$DO_NOT_DRIVE_ON_SHOULDER_LANE_3_LANE\x10\x1e\x12\x0c\n\x08\x42US_STOP\x10\x1f\x12\x0b\n\x07\x42IKEWAY\x10 \x12\x0c\n\x08SIDEWALK\x10!\x12\x1f\n\x1bPEDESTRIAN_AND_BICYCLE_ROAD\x10\"\x12\x19\n\x15PEDESTRIAN_ZONE_START\x10#\x12\x17\n\x13PEDESTRIAN_ZONE_END\x10$\x12\x16\n\x12\x42ICYCLE_ROAD_START\x10%\x12\x14\n\x10\x42ICYCLE_ROAD_END\x10&\x12\x0b\n\x07\x42USLANE\x10\'\x12\x14\n\x10\x42\x41N_ALL_VEHICLES\x10(\x12\x0c\n\x08\x42\x41N_CARS\x10)\x12\x0e\n\nBAN_TRUCKS\x10*\x12\x0f\n\x0b\x42\x41N_BICYCLE\x10+\x12\x12\n\x0e\x42\x41N_MOTORCYCLE\x10,\x12\x0b\n\x07\x42\x41N_BUS\x10-\x12\x12\n\x0e\x42\x41N_PEDESTRIAN\x10.\x12 \n\x1c\x42\x41N_CAR_TRUCK_BUS_MOTORCYCLE\x10/\x12)\n%BAN_VEHICLES_CARRYING_DANGEROUS_GOODS\x10\x30\x12\x0e\n\nMAX_WEIGHT\x10\x31\x12\r\n\tMAX_WIDTH\x10\x32\x12\x0e\n\nMAX_HEIGHT\x10\x33\x12\x0e\n\nMAX_LENGTH\x10\x34\x12\x0c\n\x08NO_ENTRY\x10\x35\x12\x1c\n\x18\x45NVIRONMENTAL_ZONE_START\x10\x36\x12\x1a\n\x16\x45NVIRONMENTAL_ZONE_END\x10\x37\x12\n\n\x06U_TURN\x10\x38\x12\r\n\tMAX_SPEED\x10\x39\x12\x18\n\x14MAX_SPEED_ZONE_START\x10:\x12\x16\n\x12MAX_SPEED_ZONE_END\x10;\x12\r\n\tMIN_SPEED\x10<\x12\x17\n\x13NO_OVERTAKING_START\x10=\x12\x1e\n\x1aNO_OVERTAKING_TRUCKS_START\x10>\x12\x11\n\rMAX_SPEED_END\x10?\x12\x15\n\x11NO_OVERTAKING_END\x10@\x12\x1c\n\x18NO_OVERTAKING_TRUCKS_END\x10\x41\x12$\n ALL_MAX_SPEED_AND_OVERTAKING_END\x10\x42\x12\x17\n\x13NO_STOP_START_RIGHT\x10\x43\x12\x18\n\x14NO_STOP_CENTER_RIGHT\x10\x44\x12 \n\x1cRESTRICTED_STOP_CENTER_RIGHT\x10\x45\x12\x10\n\x0cRIGHT_OF_WAY\x10\x46\x12\x0c\n\x08PRIORITY\x10G\x12\x1a\n\x16PRIORITY_OVER_ONCOMING\x10H\x12\r\n\tTOWN_SIGN\x10I\x12\x12\n\x0eTOWN_SIGN_BACK\x10J\x12\x10\n\x0cPARKING_AREA\x10K\x12\x15\n\x11PARKING_AREA_LEFT\x10L\x12\x16\n\x12PARKING_AREA_RIGHT\x10M\x12\x1b\n\x17PARKING_AREA_RIGHT_LEFT\x10N\x12\x1d\n\x19TRAFFIC_CALMED_AREA_START\x10O\x12\x1b\n\x17TRAFFIC_CALMED_AREA_END\x10P\x12\n\n\x06TUNNEL\x10Q\x12\x12\n\x0e\x45MERGENCY_STOP\x10R\x12\x14\n\x10INTERSTATE_START\x10S\x12\x12\n\x0eINTERSTATE_END\x10T\x12\x11\n\rHIGHWAY_START\x10U\x12\x0f\n\x0bHIGHWAY_END\x10V\x12 \n\x1cHIGHWAY_EXIT_WITH_PLACE_NAME\x10W\x12\x0e\n\nEXIT_ROUTE\x10X\x12\x10\n\x0cHIGHWAY_EXIT\x10Y\x12\x11\n\rEXIT_BUILT_UP\x10Z\x12\x10\n\x0c\x45XIT_GENERAL\x10[\x12\x18\n\x14PEDESTRIANS_CROSSING\x10\\\x12\x19\n\x15WATER_PROTECTION_ZONE\x10]\x12\x16\n\x12TRAFFIC_ASSISTANTS\x10^\x12\x0c\n\x08\x44\x45\x41\x44_END\x10_\x12\n\n\x06POLICE\x10`\x12\x1a\n\x16\x45MERGENCY_CALL_STATION\x10\x61\x12\x0f\n\x0bGAS_STATION\x10\x62\x12\x19\n\x15\x43\x41MP_AND_CARAVAN_SITE\x10\x63\x12\x14\n\x10\x41TTRACTION_POINT\x10\x64\x12\x13\n\x0fTOURISTIC_ROUTE\x10\x65\x12\x1b\n\x17NEARBY_ATTRACTION_POINT\x10\x66\x12\x18\n\x14HIGHWAY_INTERSECTION\x10g\x12\x1e\n\x1a\x44IRECTION_ARROW_SIGN_MULTI\x10h\x12\x1f\n\x1b\x44IRECTION_ARROW_SIGN_SINGLE\x10i\x12\x1f\n\x1b\x44IRECTION_SIGN_CONSOLIDATED\x10j\x12\x1e\n\x1a\x45XPRESSWAY_ARROW_DIRECTION\x10k\x12*\n&ARROW_SIGN_POST_POINT_OF_INTEREST_LEFT\x10l\x12\x0b\n\x07STATION\x10m\x12\x14\n\x10GUIDE_SIGN_TABLE\x10n\x12\x15\n\x11\x41\x44VANCE_DIRECTION\x10o\x12\x13\n\x0f\x44IRECTIONS_SIGN\x10p\x12\"\n\x1e\x45XPRESSWAY_ENTRANCE_DIRECTIONS\x10q\x12\x1b\n\x17INTERSTATE_ANNOUNCEMENT\x10r\x12 \n\x1cINTERSTATE_ADVANCE_DIRECTION\x10s\x12 \n\x1cHIGHWAY_EXIT_AHEAD_100_METER\x10t\x12 \n\x1cHIGHWAY_EXIT_AHEAD_200_METER\x10u\x12 \n\x1cHIGHWAY_EXIT_AHEAD_300_METER\x10v\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_100_METRES\x10w\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_200_METRES\x10x\x12\x1e\n\x1a\x45XPRESSWAY_EXIT_300_METRES\x10y\x12\x17\n\x13INTERSTATE_DISTANCE\x10z\x12\x11\n\rDETOUR_SKETCH\x10{\x12\x13\n\x0f\x44\x45TOUR_STRAIGHT\x10|\x12\x19\n\x15\x44\x45TOUR_ON_DEMAND_LEFT\x10}\x12%\n!DETOUR_ON_DEMAND_GET_IN_LEFT_LANE\x10~\x12\'\n#DETOUR_ON_DEMAND_ANNOUNCEMENT_RIGHT\x10\x7f\x12\x1b\n\x16\x44\x45TOUR_ON_DEMAND_RIGHT\x10\x80\x01\x12\'\n\"DETOUR_ON_DEMAND_GET_IN_RIGHT_LANE\x10\x81\x01\x12%\n DETOUR_ON_DEMAND_STRAIGHTFORWARD\x10\x82\x01\x12%\n TRANSITION_3_LEFT_2_TRANSITIONED\x10\x83\x01\x12!\n\x1cTRANSITION_1_LEFT_1_STRAIGHT\x10\x84\x01\x12\x17\n\x12TRANSITION_3_RIGHT\x10\x85\x01\x12%\n LANE_BOARD_NO_OPPOSITE_TWO_LANES\x10\x86\x01\x12\"\n\x1dTHREE_LANES_NO_ONCOMING_LANES\x10\x87\x01\x12!\n\x1c\x46OUR_LANES_NO_ONCOMING_LANES\x10\x88\x01\x12!\n\x1c\x46IVE_LANES_NO_ONCOMING_LANES\x10\x89\x01\x12.\n)LANE_BOARD_3_LANES_NO_OPPOSITE_WITH_SIGNS\x10\x8a\x01\x12&\n!NARROWING_LANES_1_LANE_FROM_RIGHT\x10\x8b\x01\x12%\n NARROWING_LANES_1_LANE_FROM_LEFT\x10\x8c\x01\x12(\n#NARROWING_LANES_2_LANES_PLUS_1_LEFT\x10\x8d\x01\x12>\n9FOUR_LANES_NO_ONCOMING_TRAFFIC_TWO_RIGHT_LANES_TURN_RIGHT\x10\x8e\x01\x12+\n&MERGING_LANES_1_LANE_PLUS_1_LANE_RIGHT\x10\x8f\x01\x12\x0c\n\x07\x42\x41RRIER\x10\x90\x01\x12\x19\n\x14\x42\x41RRIER_GATE_100_800\x10\x91\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_100_1200\x10\x92\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_100_1600\x10\x93\x01\x12\x1a\n\x15\x42\x41RRIER_GATE_250_1600\x10\x94\x01\x12\x11\n\x0c\x42\x41RRIER_GATE\x10\x95\x01\x12+\n&ROAD_WARNING_POST_SCRAPER_BEACON_RIGHT\x10\x96\x01\x12)\n$ROAD_WARNING_POST_ARROW_BEACON_RIGHT\x10\x97\x01\x12*\n%ROAD_WARNING_POST_SCRAPER_BEACON_LEFT\x10\x98\x01\x12\x31\n,ROAD_WARNING_POST_SCRAPER_BEACON_ARROW_RIGHT\x10\x99\x01\x12,\n\'ROAD_WARNING_POST_GUIDE_UP_THREE_ARROWS\x10\x9a\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_LEFT_SINGLE\x10\x9b\x01\x12\x1e\n\x19\x44IRECTION_SIGN_LEFT_SMALL\x10\x9c\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_LEFT_MEDIUM\x10\x9d\x01\x12\x1e\n\x19\x44IRECTION_SIGN_LEFT_LARGE\x10\x9e\x01\x12 \n\x1b\x44IRECTION_SIGN_RIGHT_SINGLE\x10\x9f\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_RIGHT_SMALL\x10\xa0\x01\x12 \n\x1b\x44IRECTION_SIGN_RIGHT_MEDIUM\x10\xa1\x01\x12\x1f\n\x1a\x44IRECTION_SIGN_RIGHT_LARGE\x10\xa2\x01\x12\x18\n\x13WARNING_PANEL_RIGHT\x10\xa3\x01\x12\x17\n\x12WARNING_PANEL_LEFT\x10\xa4\x01\x12!\n\x1cWARNING_PANEL_STRAIGHT_BROAD\x10\xa5\x01\x12 \n\x1bWARNING_PANEL_STRAIGHT_HIGH\x10\xa6\x01\x12\'\n\"GUIDE_SILL_WITH_GUIDE_BEACON_RIGHT\x10\xa7\x01\x12\'\n\"GUIDE_RAIL_WITH_GUIDE_BEACON_RIGHT\x10\xa8\x01\x12(\n#GUIDE_PANEL_WITH_GUIDE_BEACON_RIGHT\x10\xa9\x01\x12\x10\n\x0bGREEN_ARROW\x10\xaa\x01\x12\x1c\n\x17\x41\x44\x44ITION_LEFT_DIRECTION\x10\xab\x01\x12\x1e\n\x19\x41\x44\x44ITION_LEFT_DIRECTION_1\x10\xac\x01\x12)\n$ADDITION_LEFT_DIRECTION_DANGER_POINT\x10\xad\x01\x12\x1f\n\x1a\x41\x44\x44ITION_RIGHT_DIRECTION_1\x10\xae\x01\x12*\n%ADDITION_RIGHT_DIRECTION_DANGER_POINT\x10\xaf\x01\x12(\n#ADDITION_BOTH_DIRECTIONS_HORIZONTAL\x10\xb0\x01\x12&\n!ADDITION_BOTH_DIRECTIONS_VERTICAL\x10\xb1\x01\x12 \n\x1b\x41\x44\x44ITION_VALID_FOR_X_METERS\x10\xb2\x01\x12$\n\x1f\x41\x44\x44ITION_VALID_FOR_X_KILOMETERS\x10\xb3\x01\x12=\n8ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_RIGHT_YIELD\x10\xb4\x01\x12=\n8ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_RIGHT_YIELD\x10\xb5\x01\x12\x37\n2ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD\x10\xb6\x01\x12\x34\n/ADDITION_LEFT_TURNING_PRIORITY_WITH_RIGHT_YIELD\x10\xb7\x01\x12\x37\n2ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD\x10\xb8\x01\x12=\n8ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_LEFT_YIELD\x10\xb9\x01\x12=\n8ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_LEFT_YIELD\x10\xba\x01\x12\x38\n3ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD\x10\xbb\x01\x12\x34\n/ADDITION_RIGHT_TURNING_PRIORITY_WITH_LEFT_YIELD\x10\xbc\x01\x12\x38\n3ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD\x10\xbd\x01\x12\x1f\n\x1a\x41\x44\x44ITION_VALID_IN_X_METERS\x10\xbe\x01\x12#\n\x1e\x41\x44\x44ITION_VALID_IN_X_KILOMETERS\x10\xbf\x01\x12%\n ADDITION_VALID_IN_200_KILOMETERS\x10\xc0\x01\x12!\n\x1c\x41\x44\x44ITION_VALID_IN_400_METRES\x10\xc1\x01\x12!\n\x1c\x41\x44\x44ITION_VALID_IN_600_METRES\x10\xc2\x01\x12#\n\x1e\x41\x44\x44ITION_VALID_IN_2_KILOMETERS\x10\xc3\x01\x12\x19\n\x14\x41\x44\x44ITION_OIL_ON_ROAD\x10\xc4\x01\x12\x13\n\x0e\x41\x44\x44ITION_SMOKE\x10\xc5\x01\x12\x1a\n\x15\x41\x44\x44ITION_LOOSE_GRAVEL\x10\xc6\x01\x12 \n\x1b\x41\x44\x44ITION_BUILDING_SITE_EXIT\x10\xc7\x01\x12\x1a\n\x15\x41\x44\x44ITION_DAMAGED_ROAD\x10\xc9\x01\x12\x18\n\x13\x41\x44\x44ITION_DIRTY_ROAD\x10\xca\x01\x12!\n\x1c\x41\x44\x44ITION_DANGER_OF_COLLISION\x10\xcb\x01\x12\x1c\n\x17\x41\x44\x44ITION_TOAD_MIGRATION\x10\xcc\x01\x12\"\n\x1d\x41\x44\x44ITION_DANGER_OF_CONGESTION\x10\xcd\x01\x12*\n%ADDITION_RESTRICTED_VIEW_DUE_TO_TREES\x10\xce\x01\x12\x1c\n\x17\x44\x41NGER_INDICATION_SMOKE\x10\xcf\x01\x12&\n!ADDITION_CHILDREN_PLAYING_ON_ROAD\x10\xd0\x01\x12#\n\x1e\x41\x44\x44ITION_WINTER_SPORTS_ALLOWED\x10\xd1\x01\x12\x38\n3ADDITION_TRAILERS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS\x10\xd2\x01\x12\x38\n3ADDITION_CARAVANS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS\x10\xd3\x01\x12\x1d\n\x18\x41\x44\x44ITION_ROLLING_HIGHWAY\x10\xd4\x01\x12\x1a\n\x15\x41\x44\x44ITION_LOADING_AREA\x10\xd5\x01\x12\x11\n\x0c\x41\x44\x44ITION_END\x10\xd6\x01\x12\x1e\n\x19\x41\x44\x44ITION_GET_OFF_BICYCLES\x10\xd7\x01\x12\x17\n\x12\x41\x44\x44ITION_NO_MOPEDS\x10\xd8\x01\x12 \n\x1b\x41\x44\x44ITION_GREEN_WAVE_AT_KM_H\x10\xd9\x01\x12\x1e\n\x19\x41\x44\x44ITION_STOP_HERE_AT_RED\x10\xda\x01\x12\x1b\n\x16\x41\x44\x44ITION_NOISE_CONTROL\x10\xdb\x01\x12\x1f\n\x1a\x41\x44\x44ITION_INFLOW_REGULATION\x10\xdc\x01\x12\x1c\n\x17\x41\x44\x44ITION_SECONDARY_LANE\x10\xdd\x01\x12\x14\n\x0f\x41\x44\x44ITION_SCHOOL\x10\xde\x01\x12\x1a\n\x15\x41\x44\x44ITION_KINDERGARTEN\x10\xdf\x01\x12\x1d\n\x18\x41\x44\x44ITION_RETIREMENT_HOME\x10\xe0\x01\x12\x16\n\x11\x41\x44\x44ITION_HOSPITAL\x10\xe1\x01\x12!\n\x1c\x41\x44\x44ITION_RESIDENTS_PERMITTED\x10\xe2\x01\x12 \n\x1b\x41\x44\x44ITION_BICYCLES_PERMITTED\x10\xe3\x01\x12\x1c\n\x17\x41\x44\x44ITION_CARS_PERMITTED\x10\xe4\x01\x12#\n\x1e\x41\x44\x44ITION_AGRICULTURE_PERMITTED\x10\xe5\x01\x12\x1e\n\x19\x41\x44\x44ITION_FOREST_PERMITTED\x10\xe6\x01\x12*\n%ADDITION_AGRICULTURE_FOREST_PERMITTED\x10\xe7\x01\x12%\n ADDITION_GREEN_STICKER_PERMITTED\x10\xe8\x01\x12#\n\x1e\x41\x44\x44ITION_TIME_PERIOD_PERMITTED\x10\xe9\x01\x12\x32\n-ADDITION_MOTOR_VEHICLES_ALLOWED_MASS_3_5_TONS\x10\xea\x01\x12\x1f\n\x1a\x41\x44\x44ITION_MIN_MASS_3_5_TONS\x10\xeb\x01\x12(\n#ADDITION_NO_WATER_POLLUTANTS_LOADED\x10\xec\x01\x12\x1a\n\x15\x41LLOWED_MASS_7_5_TONS\x10\xed\x01\x12\x1f\n\x1a\x41\x44\x44ITION_VALID_ON_SHOULDER\x10\xee\x01\x12\x1c\n\x17\x41\x44\x44ITION_VALID_WHEN_WET\x10\xef\x01\x12\x19\n\x14LINE_MARKING_MISSING\x10\xf0\x01\x12\x0c\n\x07UNKNOWN\x10\xf1\x01\"\x82\x05\n\x14TrafficSignIDUsaEnum\"\xe9\x04\n\x10TrafficSignIDUsa\x12\r\n\tMAX_SPEED\x10\x00\x12\n\n\x06U_TURN\x10\x01\x12\x13\n\x0fROAD_WORK_AHEAD\x10\x02\x12\x17\n\x13NO_PARKING_ANY_TIME\x10\x03\x12\x0f\n\x0bNO_STANDING\x10\x04\x12\x11\n\rTOW_AWAY_ZONE\x10\x05\x12\x10\n\x0cONE_WAY_LEFT\x10\x06\x12\x11\n\rONE_WAY_RIGHT\x10\x07\x12\x10\n\x0c\x44O_NOT_ENTER\x10\x08\x12\x10\n\x0cNO_LEFT_TURN\x10\t\x12\x13\n\x0fRIGHT_TURN_ONLY\x10\n\x12\x13\n\x0fTURN_ONLY_LANES\x10\x0b\x12\x11\n\rNO_RIGHT_TURN\x10\x0c\x12\x0e\n\nKEEP_RIGHT\x10\r\x12\x10\n\x0cSIGNAL_AHEAD\x10\x0e\x12\x10\n\x0cLOADING_ZONE\x10\x0f\x12\x0e\n\nNO_PARKING\x10\x10\x12\x12\n\x0eLEFT_TURN_ONLY\x10\x11\x12\x17\n\x13NO_STRAIGHT_THROUGH\x10\x12\x12\x15\n\x11LEFT_REVERSE_TURN\x10\x13\x12\x16\n\x12PEDESTRIAN_WARNING\x10\x14\x12 \n\x1c\x44IAGONAL_DOWNWARD_LEFT_ARROW\x10\x15\x12\x13\n\x0fRIGHT_LANE_ENDS\x10\x16\x12\x1d\n\x19RESERVED_HANDICAP_PARKING\x10\x17\x12\x17\n\x13NO_PARKING_BUS_STOP\x10\x18\x12\x0f\n\x0bON_PAVEMENT\x10\x19\x12\x1d\n\x19\x44O_NOT_BLOCK_INTERSECTION\x10\x1a\x12\x16\n\x12WARNING_ARROW_LEFT\x10\x1b\x12\x0b\n\x07UNKNOWN\x10\x1c\"J\n\x16TrafficSignIDChinaEnum\"0\n\x12TrafficSignIDChina\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"\x88\x02\n\x16TrafficSignIDSpainEnum\"\xed\x01\n\x12TrafficSignIDSpain\x12\t\n\x05YIELD\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\x14\n\x10\x42\x41N_ALL_VEHICLES\x10\x02\x12\x0c\n\x08NO_ENTRY\x10\x03\x12\x0e\n\nBAN_TRUCKS\x10\x04\x12\x0e\n\nMAX_WEIGHT\x10\x05\x12\x0e\n\nMAX_HEIGHT\x10\x06\x12\r\n\tMAX_SPEED\x10\x07\x12\x17\n\x13NO_OVERTAKING_START\x10\x08\x12\x0f\n\x0bNO_STOPPING\x10\t\x12\x0e\n\nNO_WAITING\x10\n\x12\x18\n\x14PEDESTRIANS_CROSSING\x10\x0b\x12\x0b\n\x07UNKNOWN\x10\x0c\"L\n\x17TrafficSignIDRussiaEnum\"1\n\x13TrafficSignIDRussia\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"R\n\x1aTrafficSignIDArgentinaEnum\"4\n\x16TrafficSignIDArgentina\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"N\n\x18TrafficSignIDBelgiumEnum\"2\n\x14TrafficSignIDBelgium\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"L\n\x17TrafficSignIDFranceEnum\"1\n\x13TrafficSignIDFrance\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"L\n\x17TrafficSignIDGreeceEnum\"1\n\x13TrafficSignIDGreece\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"N\n\x18TrafficSignIDCroatiaEnum\"2\n\x14TrafficSignIDCroatia\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"J\n\x16TrafficSignIDItalyEnum\"0\n\x12TrafficSignIDItaly\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"T\n\x1bTrafficSignIDPuertoRicoEnum\"5\n\x17TrafficSignIDPuertoRico\x12\r\n\tMAX_SPEED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\"\xb8\t\n\x12TrafficSignElement\x12W\n\x12germany_element_id\x18\x01 \x01(\x0e\x32\x39.commonroad.TrafficSignIDGermanyEnum.TrafficSignIDGermanyH\x00\x12W\n\x12zamunda_element_id\x18\x02 \x01(\x0e\x32\x39.commonroad.TrafficSignIDZamundaEnum.TrafficSignIDZamundaH\x00\x12K\n\x0eusa_element_id\x18\x03 \x01(\x0e\x32\x31.commonroad.TrafficSignIDUsaEnum.TrafficSignIDUsaH\x00\x12Q\n\x10\x63hina_element_id\x18\x04 \x01(\x0e\x32\x35.commonroad.TrafficSignIDChinaEnum.TrafficSignIDChinaH\x00\x12Q\n\x10spain_element_id\x18\x05 \x01(\x0e\x32\x35.commonroad.TrafficSignIDSpainEnum.TrafficSignIDSpainH\x00\x12T\n\x11russia_element_id\x18\x07 \x01(\x0e\x32\x37.commonroad.TrafficSignIDRussiaEnum.TrafficSignIDRussiaH\x00\x12]\n\x14\x61rgentina_element_id\x18\x08 \x01(\x0e\x32=.commonroad.TrafficSignIDArgentinaEnum.TrafficSignIDArgentinaH\x00\x12W\n\x12\x62\x65lgium_element_id\x18\t \x01(\x0e\x32\x39.commonroad.TrafficSignIDBelgiumEnum.TrafficSignIDBelgiumH\x00\x12T\n\x11\x66rance_element_id\x18\n \x01(\x0e\x32\x37.commonroad.TrafficSignIDFranceEnum.TrafficSignIDFranceH\x00\x12T\n\x11greece_element_id\x18\x0b \x01(\x0e\x32\x37.commonroad.TrafficSignIDGreeceEnum.TrafficSignIDGreeceH\x00\x12W\n\x12\x63roatia_element_id\x18\x0c \x01(\x0e\x32\x39.commonroad.TrafficSignIDCroatiaEnum.TrafficSignIDCroatiaH\x00\x12Q\n\x10italy_element_id\x18\r \x01(\x0e\x32\x35.commonroad.TrafficSignIDItalyEnum.TrafficSignIDItalyH\x00\x12\x61\n\x16puerto_rico_element_id\x18\x0e \x01(\x0e\x32?.commonroad.TrafficSignIDPuertoRicoEnum.TrafficSignIDPuertoRicoH\x00\x12\x19\n\x11\x61\x64\x64itional_values\x18\x0f \x03(\tB\x19\n\x17traffic_sign_element_id\"\xb6\x01\n\x0bTrafficSign\x12\x17\n\x0ftraffic_sign_id\x18\x01 \x02(\r\x12=\n\x15traffic_sign_elements\x18\x02 \x03(\x0b\x32\x1e.commonroad.TrafficSignElement\x12\x19\n\x11\x66irst_occurrences\x18\x03 \x03(\r\x12#\n\x08position\x18\x04 \x01(\x0b\x32\x11.commonroad.Point\x12\x0f\n\x07virtual\x18\x05 \x01(\x08'
  ,
  dependencies=[util__pb2.DESCRIPTOR,])



_TRAFFICSIGNIDGERMANYENUM_TRAFFICSIGNIDGERMANY = _descriptor.EnumDescriptor(
  name='TrafficSignIDGermany',
  full_name='commonroad.TrafficSignIDGermanyEnum.TrafficSignIDGermany',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WARNING_DANGER_SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_RIGHT_BEFORE_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_LEFT_CURVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_RIGHT_CURVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_STEEP_HILL_DOWNWARDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_SLIPPERY_ROAD', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_CONSTRUCTION_SITE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_TRAFFIC_QUEUES_LIKELY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ONCOMING_TRAFFIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_TRAFFIC_LIGHTS_AHEAD', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PEDESTRIANS_RIGHT', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PEDESTRIANS_LEFT', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_CROSSING_CYCLIST', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ANIMAL_CROSSING_RIGHT', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_LOOSE_GRAVEL', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAILWAY', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_OPPOSITE_DIRECTION', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT_AHEAD', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT_AHEAD', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEEP_STRAIGHT_AHEAD', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_DIRECTION_RIGHT', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUNDABOUT', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONEWAY_RIGHT', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONEWAY_LEFT', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_PASSING_LEFT', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_PASSING_RIGHT', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE_2_LANE', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE_3_LANE', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_STOP', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIKEWAY', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_SIDEWALK', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_AND_BICYCLE_ROAD', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ZONE_START', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ZONE_END', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_ROAD_START', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_ROAD_END', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_LANE', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_ALL_VEHICLES', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_CARS', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_TRUCKS', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_BICYCLE', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_MOTORCYCLE', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_BUS', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_PEDESTRIAN', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_CAR_TRUCK_BUS_MOTORCYCLE', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_VEHICLES_CARRYING_DANGEROUS_GOODS', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_WEIGHT', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_WIDTH', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_HEIGHT', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_LENGTH', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_ENTRY', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENTAL_ZONE_START', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENTAL_ZONE_END', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_ZONE_START', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_ZONE_END', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN_SPEED', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_START', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_TRUCKS_START', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_END', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_END', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_TRUCKS_END', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_MAX_SPEED_AND_OVERTAKING_END', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_START_RIGHT', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_CENTER_RIGHT', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTRICTED_STOP_CENTER_RIGHT', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_OF_WAY', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_OVER_ONCOMING', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOWN_SIGN', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOWN_SIGN_BACK', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_LEFT', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_RIGHT', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_RIGHT_LEFT', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_CALMED_AREA_START', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_CALMED_AREA_END', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNNEL', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERYGECNY_STOP', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_START', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_END', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_START', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_END', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_WITH_PLACE_NAME', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_ROUTE', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_BUILT_UP', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_GENERAL', index=91, number=91,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIANS_CROSSING', index=92, number=92,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WATER_PROTECTION_ZONE', index=93, number=93,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_ASSISTANTS', index=94, number=94,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD_END', index=95, number=95,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POLICE', index=96, number=96,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_CALL_STATION', index=97, number=97,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAS_STATION', index=98, number=98,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMP_AND_CARAVAN_SITE', index=99, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATTRACTION_POINT', index=100, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOURISTIC_ROUTE', index=101, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEARBY_ATTRACTION_POINT', index=102, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_INTERSECTION', index=103, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_ARROW_SIGN_MULTI', index=104, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_ARROW_SIGN_SINGLE', index=105, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_CONSOLIDATED', index=106, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_ARROW_DIRECTION', index=107, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_SIGN_POST_POINT_OF_INTEREST_LEFT', index=108, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATION', index=109, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_SIGN_TABLE', index=110, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADVANCE_DIRECTION', index=111, number=111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTIONS_SIGN', index=112, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_ENTRANCE_DIRECTIONS', index=113, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_ANNOUNCEMENT', index=114, number=114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_ADVANCE_DIRECTION', index=115, number=115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_100_METER', index=116, number=116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_200_METER', index=117, number=117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_300_METER', index=118, number=118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_100_METRES', index=119, number=119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_200_METRES', index=120, number=120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_300_METRES', index=121, number=121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_DISTANCE', index=122, number=122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_SKETCH', index=123, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_STRAIGHT', index=124, number=124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_LEFT', index=125, number=125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_GET_IN_LEFT_LANE', index=126, number=126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_ANNOUNCEMENT_RIGHT', index=127, number=127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_RIGHT', index=128, number=128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_GET_IN_RIGHT_LANE', index=129, number=129,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_STRAIGHTFORWARD', index=130, number=130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_3_LEFT_2_TRANSITIONED', index=131, number=131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_1_LEFT_1_STRAIGHT', index=132, number=132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_3_RIGHT', index=133, number=133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_BOARD_NO_OPPOSITE_TWO_LANES', index=134, number=134,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THREE_LANES_NO_ONCOMING_LANES', index=135, number=135,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOUR_LANES_NO_ONCOMING_LANES', index=136, number=136,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIVE_LANES_NO_ONCOMING_LANES', index=137, number=137,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_BOARD_3_LANES_NO_OPPOSITE_WITH_SIGNS', index=138, number=138,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_1_LANE_FROM_RIGHT', index=139, number=139,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_1_LANE_FROM_LEFT', index=140, number=140,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_2_LANES_PLUS_1_LEFT', index=141, number=141,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOUR_LANES_NO_ONCOMING_TRAFFIC_TWO_RIGHT_LANES_TURN_RIGHT', index=142, number=142,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MERGING_LANES_1_LANE_PLUS_1_LANE_RIGHT', index=143, number=143,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER', index=144, number=144,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_800', index=145, number=145,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_1200', index=146, number=146,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_1600', index=147, number=147,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_250_1600', index=148, number=148,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE', index=149, number=149,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_RIGHT', index=150, number=150,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_ARROW_BEACON_RIGHT', index=151, number=151,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_LEFT', index=152, number=152,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_ARROW_RIGHT', index=153, number=153,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_GUIDE_UP_THREE_ARROWS', index=154, number=154,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_SINGLE', index=155, number=155,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_SMALL', index=156, number=156,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_MEDIUM', index=157, number=157,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_LARGE', index=158, number=158,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_SINGLE', index=159, number=159,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_SMALL', index=160, number=160,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_MEDIUM', index=161, number=161,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_LARGE', index=162, number=162,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_RIGHT', index=163, number=163,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_LEFT', index=164, number=164,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_STRAIGHT_BROAD', index=165, number=165,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_STRAIGHT_HIGH', index=166, number=166,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_SILL_WITH_GUIDE_BEACON_RIGHT', index=167, number=167,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_RAIL_WITH_GUIDE_BEACON_RIGHT', index=168, number=168,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_PANEL_WITH_GUIDE_BEACON_RIGHT', index=169, number=169,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN_ARROW', index=170, number=170,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION', index=171, number=171,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION_1', index=172, number=172,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION_DANGER_POINT', index=173, number=173,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_DIRECTION_1', index=174, number=174,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_DIRECTION_DANGER_POINT', index=175, number=175,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BOTH_DIRECTIONS_HORIZONTAL', index=176, number=176,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BOTH_DIRECTIONS_VERTICAL', index=177, number=177,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_FOR_X_METERS', index=178, number=178,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_FOR_X_KILOMETERS', index=179, number=179,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_RIGHT_YIELD', index=180, number=180,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_RIGHT_YIELD', index=181, number=181,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD', index=182, number=182,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_RIGHT_YIELD', index=183, number=183,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD', index=184, number=184,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_LEFT_YIELD', index=185, number=185,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_LEFT_YIELD', index=186, number=186,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD', index=187, number=187,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_LEFT_YIELD', index=188, number=188,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD', index=189, number=189,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_X_METERS', index=190, number=190,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_X_KILOMETERS', index=191, number=191,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_200_KILOMETERS', index=192, number=192,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_400_METRES', index=193, number=193,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_600_METRES', index=194, number=194,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_2_KILOMETERS', index=195, number=195,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_OIL_ON_ROAD', index=196, number=196,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SMOKE', index=197, number=197,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LOOSE_GRAVEL', index=198, number=198,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BUILDING_SITE_EXIT', index=199, number=199,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DAMAGED_ROAD', index=200, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DIRTY_ROAD', index=201, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DANGER_OF_COLLISION', index=202, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TOAD_MIGRATION', index=203, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DANGER_OF_CONGESTION', index=204, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RESTRICTED_VIEW_DUE_TO_TREES', index=205, number=206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DANGER_INDICATION_SMOKE', index=206, number=207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CHILDREN_PLAYING_ON_ROAD', index=207, number=208,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_WINTER_SPORTS_ALLOWED', index=208, number=209,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TRAILERS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS', index=209, number=210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CARAVANS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS', index=210, number=211,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_ROLLING_HIGHWAY', index=211, number=212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LOADING_AREA', index=212, number=213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_END', index=213, number=214,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GET_OFF_BICYCLES', index=214, number=215,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NO_MOPEDS', index=215, number=216,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GREEN_WAVE_AT_KM_H', index=216, number=217,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_STOP_HERE_AT_RED', index=217, number=218,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NOISE_CONTROL', index=218, number=219,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_INFLOW_REGULATION', index=219, number=220,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SECONDARY_LANE', index=220, number=221,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SCHOOL', index=221, number=222,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_KINDERGARTEN', index=222, number=223,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RETIREMENT_HOME', index=223, number=224,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_HOSPITAL', index=224, number=225,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RESIDENTS_PERMITTED', index=225, number=226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BICYCLES_PERMITTED', index=226, number=227,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CARS_PERMITTED', index=227, number=228,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_AGRICULTURE_PERMITTED', index=228, number=229,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_FOREST_PERMITTED', index=229, number=230,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_AGRICULTURE_FOREST_PERMITTED', index=230, number=231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GREEN_STICKER_PERMITTED', index=231, number=232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TIME_PERIOD_PERMITTED', index=232, number=233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_MOTOR_VEHICLES_ALLOWED_MASS_3_5_TONS', index=233, number=234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_MIN_MASS_3_5_TONS', index=234, number=235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NO_WATER_POLLUTANTS_LOADED', index=235, number=236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLOWED_MASS_7_5_TONS', index=236, number=237,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_ON_SHOULDER', index=237, number=238,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_WHEN_WET', index=238, number=239,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINE_MARKING_MISSING', index=239, number=240,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=240, number=241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=76,
  serialized_end=7414,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDGERMANYENUM_TRAFFICSIGNIDGERMANY)

_TRAFFICSIGNIDZAMUNDAENUM_TRAFFICSIGNIDZAMUNDA = _descriptor.EnumDescriptor(
  name='TrafficSignIDZamunda',
  full_name='commonroad.TrafficSignIDZamundaEnum.TrafficSignIDZamunda',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WARNING_DANGER_SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_RIGHT_BEFORE_LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_LEFT_CURVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_RIGHT_CURVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_STEEP_HILL_DOWNWARDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_SLIPPERY_ROAD', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_CONSTRUCTION_SITE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_TRAFFIC_QUEUES_LIKELY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ONCOMING_TRAFFIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_TRAFFIC_LIGHTS_AHEAD', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PEDESTRIANS_RIGHT', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PEDESTRIANS_LEFT', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_CROSSING_CYCLIST', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ANIMAL_CROSSING_RIGHT', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_LOOSE_GRAVEL', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAILWAY', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_OPPOSITE_DIRECTION', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_RIGHT_AHEAD', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_LEFT_AHEAD', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEEP_STRAIGHT_AHEAD', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_DIRECTION_RIGHT', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUNDABOUT', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONEWAY_RIGHT', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONEWAY_LEFT', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_PASSING_LEFT', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESCRIBED_PASSING_RIGHT', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE_2_LANE', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_DRIVE_ON_SHOULDER_LANE_3_LANE', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_STOP', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIKEWAY', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_SIDEWALK', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_AND_BICYCLE_ROAD', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ZONE_START', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ZONE_END', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_ROAD_START', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_ROAD_END', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_LANE', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_ALL_VEHICLES', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_CARS', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_TRUCKS', index=42, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_BICYCLE', index=43, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_MOTORCYCLE', index=44, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_BUS', index=45, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_PEDESTRIAN', index=46, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_CAR_TRUCK_BUS_MOTORCYCLE', index=47, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_VEHICLES_CARRYING_DANGEROUS_GOODS', index=48, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_WEIGHT', index=49, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_WIDTH', index=50, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_HEIGHT', index=51, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_LENGTH', index=52, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_ENTRY', index=53, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENTAL_ZONE_START', index=54, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENTAL_ZONE_END', index=55, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=56, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=57, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_ZONE_START', index=58, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_ZONE_END', index=59, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN_SPEED', index=60, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_START', index=61, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_TRUCKS_START', index=62, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED_END', index=63, number=63,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_END', index=64, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_TRUCKS_END', index=65, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_MAX_SPEED_AND_OVERTAKING_END', index=66, number=66,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_START_RIGHT', index=67, number=67,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_CENTER_RIGHT', index=68, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTRICTED_STOP_CENTER_RIGHT', index=69, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_OF_WAY', index=70, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY', index=71, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIORITY_OVER_ONCOMING', index=72, number=72,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOWN_SIGN', index=73, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOWN_SIGN_BACK', index=74, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA', index=75, number=75,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_LEFT', index=76, number=76,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_RIGHT', index=77, number=77,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_AREA_RIGHT_LEFT', index=78, number=78,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_CALMED_AREA_START', index=79, number=79,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_CALMED_AREA_END', index=80, number=80,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNNEL', index=81, number=81,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_STOP', index=82, number=82,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_START', index=83, number=83,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_END', index=84, number=84,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_START', index=85, number=85,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_END', index=86, number=86,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_WITH_PLACE_NAME', index=87, number=87,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_ROUTE', index=88, number=88,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT', index=89, number=89,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_BUILT_UP', index=90, number=90,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT_GENERAL', index=91, number=91,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIANS_CROSSING', index=92, number=92,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WATER_PROTECTION_ZONE', index=93, number=93,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_ASSISTANTS', index=94, number=94,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD_END', index=95, number=95,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POLICE', index=96, number=96,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_CALL_STATION', index=97, number=97,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAS_STATION', index=98, number=98,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMP_AND_CARAVAN_SITE', index=99, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ATTRACTION_POINT', index=100, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOURISTIC_ROUTE', index=101, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEARBY_ATTRACTION_POINT', index=102, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_INTERSECTION', index=103, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_ARROW_SIGN_MULTI', index=104, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_ARROW_SIGN_SINGLE', index=105, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_CONSOLIDATED', index=106, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_ARROW_DIRECTION', index=107, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARROW_SIGN_POST_POINT_OF_INTEREST_LEFT', index=108, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATION', index=109, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_SIGN_TABLE', index=110, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADVANCE_DIRECTION', index=111, number=111,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTIONS_SIGN', index=112, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_ENTRANCE_DIRECTIONS', index=113, number=113,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_ANNOUNCEMENT', index=114, number=114,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_ADVANCE_DIRECTION', index=115, number=115,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_100_METER', index=116, number=116,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_200_METER', index=117, number=117,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_EXIT_AHEAD_300_METER', index=118, number=118,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_100_METRES', index=119, number=119,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_200_METRES', index=120, number=120,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPRESSWAY_EXIT_300_METRES', index=121, number=121,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERSTATE_DISTANCE', index=122, number=122,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_SKETCH', index=123, number=123,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_STRAIGHT', index=124, number=124,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_LEFT', index=125, number=125,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_GET_IN_LEFT_LANE', index=126, number=126,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_ANNOUNCEMENT_RIGHT', index=127, number=127,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_RIGHT', index=128, number=128,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_GET_IN_RIGHT_LANE', index=129, number=129,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DETOUR_ON_DEMAND_STRAIGHTFORWARD', index=130, number=130,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_3_LEFT_2_TRANSITIONED', index=131, number=131,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_1_LEFT_1_STRAIGHT', index=132, number=132,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION_3_RIGHT', index=133, number=133,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_BOARD_NO_OPPOSITE_TWO_LANES', index=134, number=134,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THREE_LANES_NO_ONCOMING_LANES', index=135, number=135,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOUR_LANES_NO_ONCOMING_LANES', index=136, number=136,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIVE_LANES_NO_ONCOMING_LANES', index=137, number=137,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_BOARD_3_LANES_NO_OPPOSITE_WITH_SIGNS', index=138, number=138,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_1_LANE_FROM_RIGHT', index=139, number=139,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_1_LANE_FROM_LEFT', index=140, number=140,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWING_LANES_2_LANES_PLUS_1_LEFT', index=141, number=141,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOUR_LANES_NO_ONCOMING_TRAFFIC_TWO_RIGHT_LANES_TURN_RIGHT', index=142, number=142,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MERGING_LANES_1_LANE_PLUS_1_LANE_RIGHT', index=143, number=143,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER', index=144, number=144,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_800', index=145, number=145,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_1200', index=146, number=146,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_100_1600', index=147, number=147,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE_250_1600', index=148, number=148,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BARRIER_GATE', index=149, number=149,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_RIGHT', index=150, number=150,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_ARROW_BEACON_RIGHT', index=151, number=151,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_LEFT', index=152, number=152,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_SCRAPER_BEACON_ARROW_RIGHT', index=153, number=153,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WARNING_POST_GUIDE_UP_THREE_ARROWS', index=154, number=154,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_SINGLE', index=155, number=155,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_SMALL', index=156, number=156,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_MEDIUM', index=157, number=157,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_LEFT_LARGE', index=158, number=158,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_SINGLE', index=159, number=159,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_SMALL', index=160, number=160,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_MEDIUM', index=161, number=161,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECTION_SIGN_RIGHT_LARGE', index=162, number=162,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_RIGHT', index=163, number=163,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_LEFT', index=164, number=164,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_STRAIGHT_BROAD', index=165, number=165,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PANEL_STRAIGHT_HIGH', index=166, number=166,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_SILL_WITH_GUIDE_BEACON_RIGHT', index=167, number=167,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_RAIL_WITH_GUIDE_BEACON_RIGHT', index=168, number=168,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUIDE_PANEL_WITH_GUIDE_BEACON_RIGHT', index=169, number=169,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN_ARROW', index=170, number=170,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION', index=171, number=171,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION_1', index=172, number=172,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_DIRECTION_DANGER_POINT', index=173, number=173,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_DIRECTION_1', index=174, number=174,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_DIRECTION_DANGER_POINT', index=175, number=175,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BOTH_DIRECTIONS_HORIZONTAL', index=176, number=176,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BOTH_DIRECTIONS_VERTICAL', index=177, number=177,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_FOR_X_METERS', index=178, number=178,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_FOR_X_KILOMETERS', index=179, number=179,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_RIGHT_YIELD', index=180, number=180,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_RIGHT_YIELD', index=181, number=181,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD', index=182, number=182,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TURNING_PRIORITY_WITH_RIGHT_YIELD', index=183, number=183,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LEFT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD', index=184, number=184,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_LEFT_YIELD', index=185, number=185,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_LEFT_YIELD', index=186, number=186,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_OPPOSITE_YIELD', index=187, number=187,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TURNING_PRIORITY_WITH_LEFT_YIELD', index=188, number=188,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RIGHT_TRAFFIC_PRIORITY_WITH_STRAIGHT_YIELD', index=189, number=189,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_X_METERS', index=190, number=190,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_X_KILOMETERS', index=191, number=191,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_200_KILOMETERS', index=192, number=192,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_400_METRES', index=193, number=193,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_600_METRES', index=194, number=194,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_IN_2_KILOMETERS', index=195, number=195,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_OIL_ON_ROAD', index=196, number=196,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SMOKE', index=197, number=197,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LOOSE_GRAVEL', index=198, number=198,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BUILDING_SITE_EXIT', index=199, number=199,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DAMAGED_ROAD', index=200, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DIRTY_ROAD', index=201, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DANGER_OF_COLLISION', index=202, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TOAD_MIGRATION', index=203, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_DANGER_OF_CONGESTION', index=204, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RESTRICTED_VIEW_DUE_TO_TREES', index=205, number=206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DANGER_INDICATION_SMOKE', index=206, number=207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CHILDREN_PLAYING_ON_ROAD', index=207, number=208,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_WINTER_SPORTS_ALLOWED', index=208, number=209,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TRAILERS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS', index=209, number=210,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CARAVANS_ALLOWED_TO_PARK_MORE_THAN_14_DAYS', index=210, number=211,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_ROLLING_HIGHWAY', index=211, number=212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_LOADING_AREA', index=212, number=213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_END', index=213, number=214,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GET_OFF_BICYCLES', index=214, number=215,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NO_MOPEDS', index=215, number=216,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GREEN_WAVE_AT_KM_H', index=216, number=217,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_STOP_HERE_AT_RED', index=217, number=218,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NOISE_CONTROL', index=218, number=219,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_INFLOW_REGULATION', index=219, number=220,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SECONDARY_LANE', index=220, number=221,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_SCHOOL', index=221, number=222,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_KINDERGARTEN', index=222, number=223,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RETIREMENT_HOME', index=223, number=224,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_HOSPITAL', index=224, number=225,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_RESIDENTS_PERMITTED', index=225, number=226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_BICYCLES_PERMITTED', index=226, number=227,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_CARS_PERMITTED', index=227, number=228,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_AGRICULTURE_PERMITTED', index=228, number=229,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_FOREST_PERMITTED', index=229, number=230,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_AGRICULTURE_FOREST_PERMITTED', index=230, number=231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_GREEN_STICKER_PERMITTED', index=231, number=232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_TIME_PERIOD_PERMITTED', index=232, number=233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_MOTOR_VEHICLES_ALLOWED_MASS_3_5_TONS', index=233, number=234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_MIN_MASS_3_5_TONS', index=234, number=235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_NO_WATER_POLLUTANTS_LOADED', index=235, number=236,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLOWED_MASS_7_5_TONS', index=236, number=237,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_ON_SHOULDER', index=237, number=238,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDITION_VALID_WHEN_WET', index=238, number=239,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINE_MARKING_MISSING', index=239, number=240,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=240, number=241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7446,
  serialized_end=14783,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDZAMUNDAENUM_TRAFFICSIGNIDZAMUNDA)

_TRAFFICSIGNIDUSAENUM_TRAFFICSIGNIDUSA = _descriptor.EnumDescriptor(
  name='TrafficSignIDUsa',
  full_name='commonroad.TrafficSignIDUsaEnum.TrafficSignIDUsa',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROAD_WORK_AHEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_PARKING_ANY_TIME', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STANDING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOW_AWAY_ZONE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_WAY_LEFT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONE_WAY_RIGHT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_ENTER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_LEFT_TURN', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN_ONLY', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TURN_ONLY_LANES', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_RIGHT_TURN', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEEP_RIGHT', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGNAL_AHEAD', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOADING_ZONE', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_PARKING', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN_ONLY', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STRAIGHT_THROUGH', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_REVERSE_TURN', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_WARNING', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIAGONAL_DOWNWARD_LEFT_ARROW', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_LANE_ENDS', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESERVED_HANDICAP_PARKING', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_PARKING_BUS_STOP', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_PAVEMENT', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_BLOCK_INTERSECTION', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ARROW_LEFT', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14811,
  serialized_end=15428,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDUSAENUM_TRAFFICSIGNIDUSA)

_TRAFFICSIGNIDCHINAENUM_TRAFFICSIGNIDCHINA = _descriptor.EnumDescriptor(
  name='TrafficSignIDChina',
  full_name='commonroad.TrafficSignIDChinaEnum.TrafficSignIDChina',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15456,
  serialized_end=15504,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDCHINAENUM_TRAFFICSIGNIDCHINA)

_TRAFFICSIGNIDSPAINENUM_TRAFFICSIGNIDSPAIN = _descriptor.EnumDescriptor(
  name='TrafficSignIDSpain',
  full_name='commonroad.TrafficSignIDSpainEnum.TrafficSignIDSpain',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YIELD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_ALL_VEHICLES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_ENTRY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAN_TRUCKS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_WEIGHT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_HEIGHT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_OVERTAKING_START', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_STOPPING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_WAITING', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIANS_CROSSING', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15534,
  serialized_end=15771,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDSPAINENUM_TRAFFICSIGNIDSPAIN)

_TRAFFICSIGNIDRUSSIAENUM_TRAFFICSIGNIDRUSSIA = _descriptor.EnumDescriptor(
  name='TrafficSignIDRussia',
  full_name='commonroad.TrafficSignIDRussiaEnum.TrafficSignIDRussia',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15800,
  serialized_end=15849,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDRUSSIAENUM_TRAFFICSIGNIDRUSSIA)

_TRAFFICSIGNIDARGENTINAENUM_TRAFFICSIGNIDARGENTINA = _descriptor.EnumDescriptor(
  name='TrafficSignIDArgentina',
  full_name='commonroad.TrafficSignIDArgentinaEnum.TrafficSignIDArgentina',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15881,
  serialized_end=15933,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDARGENTINAENUM_TRAFFICSIGNIDARGENTINA)

_TRAFFICSIGNIDBELGIUMENUM_TRAFFICSIGNIDBELGIUM = _descriptor.EnumDescriptor(
  name='TrafficSignIDBelgium',
  full_name='commonroad.TrafficSignIDBelgiumEnum.TrafficSignIDBelgium',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15963,
  serialized_end=16013,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDBELGIUMENUM_TRAFFICSIGNIDBELGIUM)

_TRAFFICSIGNIDFRANCEENUM_TRAFFICSIGNIDFRANCE = _descriptor.EnumDescriptor(
  name='TrafficSignIDFrance',
  full_name='commonroad.TrafficSignIDFranceEnum.TrafficSignIDFrance',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16042,
  serialized_end=16091,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDFRANCEENUM_TRAFFICSIGNIDFRANCE)

_TRAFFICSIGNIDGREECEENUM_TRAFFICSIGNIDGREECE = _descriptor.EnumDescriptor(
  name='TrafficSignIDGreece',
  full_name='commonroad.TrafficSignIDGreeceEnum.TrafficSignIDGreece',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16120,
  serialized_end=16169,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDGREECEENUM_TRAFFICSIGNIDGREECE)

_TRAFFICSIGNIDCROATIAENUM_TRAFFICSIGNIDCROATIA = _descriptor.EnumDescriptor(
  name='TrafficSignIDCroatia',
  full_name='commonroad.TrafficSignIDCroatiaEnum.TrafficSignIDCroatia',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16199,
  serialized_end=16249,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDCROATIAENUM_TRAFFICSIGNIDCROATIA)

_TRAFFICSIGNIDITALYENUM_TRAFFICSIGNIDITALY = _descriptor.EnumDescriptor(
  name='TrafficSignIDItaly',
  full_name='commonroad.TrafficSignIDItalyEnum.TrafficSignIDItaly',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16277,
  serialized_end=16325,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDITALYENUM_TRAFFICSIGNIDITALY)

_TRAFFICSIGNIDPUERTORICOENUM_TRAFFICSIGNIDPUERTORICO = _descriptor.EnumDescriptor(
  name='TrafficSignIDPuertoRico',
  full_name='commonroad.TrafficSignIDPuertoRicoEnum.TrafficSignIDPuertoRico',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAX_SPEED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16358,
  serialized_end=16411,
)
_sym_db.RegisterEnumDescriptor(_TRAFFICSIGNIDPUERTORICOENUM_TRAFFICSIGNIDPUERTORICO)


_TRAFFICSIGNIDGERMANYENUM = _descriptor.Descriptor(
  name='TrafficSignIDGermanyEnum',
  full_name='commonroad.TrafficSignIDGermanyEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDGERMANYENUM_TRAFFICSIGNIDGERMANY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=7414,
)


_TRAFFICSIGNIDZAMUNDAENUM = _descriptor.Descriptor(
  name='TrafficSignIDZamundaEnum',
  full_name='commonroad.TrafficSignIDZamundaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDZAMUNDAENUM_TRAFFICSIGNIDZAMUNDA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7417,
  serialized_end=14783,
)


_TRAFFICSIGNIDUSAENUM = _descriptor.Descriptor(
  name='TrafficSignIDUsaEnum',
  full_name='commonroad.TrafficSignIDUsaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDUSAENUM_TRAFFICSIGNIDUSA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14786,
  serialized_end=15428,
)


_TRAFFICSIGNIDCHINAENUM = _descriptor.Descriptor(
  name='TrafficSignIDChinaEnum',
  full_name='commonroad.TrafficSignIDChinaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDCHINAENUM_TRAFFICSIGNIDCHINA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15430,
  serialized_end=15504,
)


_TRAFFICSIGNIDSPAINENUM = _descriptor.Descriptor(
  name='TrafficSignIDSpainEnum',
  full_name='commonroad.TrafficSignIDSpainEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDSPAINENUM_TRAFFICSIGNIDSPAIN,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15507,
  serialized_end=15771,
)


_TRAFFICSIGNIDRUSSIAENUM = _descriptor.Descriptor(
  name='TrafficSignIDRussiaEnum',
  full_name='commonroad.TrafficSignIDRussiaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDRUSSIAENUM_TRAFFICSIGNIDRUSSIA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15773,
  serialized_end=15849,
)


_TRAFFICSIGNIDARGENTINAENUM = _descriptor.Descriptor(
  name='TrafficSignIDArgentinaEnum',
  full_name='commonroad.TrafficSignIDArgentinaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDARGENTINAENUM_TRAFFICSIGNIDARGENTINA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15851,
  serialized_end=15933,
)


_TRAFFICSIGNIDBELGIUMENUM = _descriptor.Descriptor(
  name='TrafficSignIDBelgiumEnum',
  full_name='commonroad.TrafficSignIDBelgiumEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDBELGIUMENUM_TRAFFICSIGNIDBELGIUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15935,
  serialized_end=16013,
)


_TRAFFICSIGNIDFRANCEENUM = _descriptor.Descriptor(
  name='TrafficSignIDFranceEnum',
  full_name='commonroad.TrafficSignIDFranceEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDFRANCEENUM_TRAFFICSIGNIDFRANCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16015,
  serialized_end=16091,
)


_TRAFFICSIGNIDGREECEENUM = _descriptor.Descriptor(
  name='TrafficSignIDGreeceEnum',
  full_name='commonroad.TrafficSignIDGreeceEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDGREECEENUM_TRAFFICSIGNIDGREECE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16093,
  serialized_end=16169,
)


_TRAFFICSIGNIDCROATIAENUM = _descriptor.Descriptor(
  name='TrafficSignIDCroatiaEnum',
  full_name='commonroad.TrafficSignIDCroatiaEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDCROATIAENUM_TRAFFICSIGNIDCROATIA,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16171,
  serialized_end=16249,
)


_TRAFFICSIGNIDITALYENUM = _descriptor.Descriptor(
  name='TrafficSignIDItalyEnum',
  full_name='commonroad.TrafficSignIDItalyEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDITALYENUM_TRAFFICSIGNIDITALY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16251,
  serialized_end=16325,
)


_TRAFFICSIGNIDPUERTORICOENUM = _descriptor.Descriptor(
  name='TrafficSignIDPuertoRicoEnum',
  full_name='commonroad.TrafficSignIDPuertoRicoEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRAFFICSIGNIDPUERTORICOENUM_TRAFFICSIGNIDPUERTORICO,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16327,
  serialized_end=16411,
)


_TRAFFICSIGNELEMENT = _descriptor.Descriptor(
  name='TrafficSignElement',
  full_name='commonroad.TrafficSignElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='germany_element_id', full_name='commonroad.TrafficSignElement.germany_element_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zamunda_element_id', full_name='commonroad.TrafficSignElement.zamunda_element_id', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usa_element_id', full_name='commonroad.TrafficSignElement.usa_element_id', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='china_element_id', full_name='commonroad.TrafficSignElement.china_element_id', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spain_element_id', full_name='commonroad.TrafficSignElement.spain_element_id', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='russia_element_id', full_name='commonroad.TrafficSignElement.russia_element_id', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='argentina_element_id', full_name='commonroad.TrafficSignElement.argentina_element_id', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='belgium_element_id', full_name='commonroad.TrafficSignElement.belgium_element_id', index=7,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='france_element_id', full_name='commonroad.TrafficSignElement.france_element_id', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='greece_element_id', full_name='commonroad.TrafficSignElement.greece_element_id', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='croatia_element_id', full_name='commonroad.TrafficSignElement.croatia_element_id', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='italy_element_id', full_name='commonroad.TrafficSignElement.italy_element_id', index=11,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='puerto_rico_element_id', full_name='commonroad.TrafficSignElement.puerto_rico_element_id', index=12,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additional_values', full_name='commonroad.TrafficSignElement.additional_values', index=13,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='traffic_sign_element_id', full_name='commonroad.TrafficSignElement.traffic_sign_element_id',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16414,
  serialized_end=17622,
)


_TRAFFICSIGN = _descriptor.Descriptor(
  name='TrafficSign',
  full_name='commonroad.TrafficSign',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traffic_sign_id', full_name='commonroad.TrafficSign.traffic_sign_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_sign_elements', full_name='commonroad.TrafficSign.traffic_sign_elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_occurrences', full_name='commonroad.TrafficSign.first_occurrences', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='commonroad.TrafficSign.position', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual', full_name='commonroad.TrafficSign.virtual', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17625,
  serialized_end=17807,
)

_TRAFFICSIGNIDGERMANYENUM_TRAFFICSIGNIDGERMANY.containing_type = _TRAFFICSIGNIDGERMANYENUM
_TRAFFICSIGNIDZAMUNDAENUM_TRAFFICSIGNIDZAMUNDA.containing_type = _TRAFFICSIGNIDZAMUNDAENUM
_TRAFFICSIGNIDUSAENUM_TRAFFICSIGNIDUSA.containing_type = _TRAFFICSIGNIDUSAENUM
_TRAFFICSIGNIDCHINAENUM_TRAFFICSIGNIDCHINA.containing_type = _TRAFFICSIGNIDCHINAENUM
_TRAFFICSIGNIDSPAINENUM_TRAFFICSIGNIDSPAIN.containing_type = _TRAFFICSIGNIDSPAINENUM
_TRAFFICSIGNIDRUSSIAENUM_TRAFFICSIGNIDRUSSIA.containing_type = _TRAFFICSIGNIDRUSSIAENUM
_TRAFFICSIGNIDARGENTINAENUM_TRAFFICSIGNIDARGENTINA.containing_type = _TRAFFICSIGNIDARGENTINAENUM
_TRAFFICSIGNIDBELGIUMENUM_TRAFFICSIGNIDBELGIUM.containing_type = _TRAFFICSIGNIDBELGIUMENUM
_TRAFFICSIGNIDFRANCEENUM_TRAFFICSIGNIDFRANCE.containing_type = _TRAFFICSIGNIDFRANCEENUM
_TRAFFICSIGNIDGREECEENUM_TRAFFICSIGNIDGREECE.containing_type = _TRAFFICSIGNIDGREECEENUM
_TRAFFICSIGNIDCROATIAENUM_TRAFFICSIGNIDCROATIA.containing_type = _TRAFFICSIGNIDCROATIAENUM
_TRAFFICSIGNIDITALYENUM_TRAFFICSIGNIDITALY.containing_type = _TRAFFICSIGNIDITALYENUM
_TRAFFICSIGNIDPUERTORICOENUM_TRAFFICSIGNIDPUERTORICO.containing_type = _TRAFFICSIGNIDPUERTORICOENUM
_TRAFFICSIGNELEMENT.fields_by_name['germany_element_id'].enum_type = _TRAFFICSIGNIDGERMANYENUM_TRAFFICSIGNIDGERMANY
_TRAFFICSIGNELEMENT.fields_by_name['zamunda_element_id'].enum_type = _TRAFFICSIGNIDZAMUNDAENUM_TRAFFICSIGNIDZAMUNDA
_TRAFFICSIGNELEMENT.fields_by_name['usa_element_id'].enum_type = _TRAFFICSIGNIDUSAENUM_TRAFFICSIGNIDUSA
_TRAFFICSIGNELEMENT.fields_by_name['china_element_id'].enum_type = _TRAFFICSIGNIDCHINAENUM_TRAFFICSIGNIDCHINA
_TRAFFICSIGNELEMENT.fields_by_name['spain_element_id'].enum_type = _TRAFFICSIGNIDSPAINENUM_TRAFFICSIGNIDSPAIN
_TRAFFICSIGNELEMENT.fields_by_name['russia_element_id'].enum_type = _TRAFFICSIGNIDRUSSIAENUM_TRAFFICSIGNIDRUSSIA
_TRAFFICSIGNELEMENT.fields_by_name['argentina_element_id'].enum_type = _TRAFFICSIGNIDARGENTINAENUM_TRAFFICSIGNIDARGENTINA
_TRAFFICSIGNELEMENT.fields_by_name['belgium_element_id'].enum_type = _TRAFFICSIGNIDBELGIUMENUM_TRAFFICSIGNIDBELGIUM
_TRAFFICSIGNELEMENT.fields_by_name['france_element_id'].enum_type = _TRAFFICSIGNIDFRANCEENUM_TRAFFICSIGNIDFRANCE
_TRAFFICSIGNELEMENT.fields_by_name['greece_element_id'].enum_type = _TRAFFICSIGNIDGREECEENUM_TRAFFICSIGNIDGREECE
_TRAFFICSIGNELEMENT.fields_by_name['croatia_element_id'].enum_type = _TRAFFICSIGNIDCROATIAENUM_TRAFFICSIGNIDCROATIA
_TRAFFICSIGNELEMENT.fields_by_name['italy_element_id'].enum_type = _TRAFFICSIGNIDITALYENUM_TRAFFICSIGNIDITALY
_TRAFFICSIGNELEMENT.fields_by_name['puerto_rico_element_id'].enum_type = _TRAFFICSIGNIDPUERTORICOENUM_TRAFFICSIGNIDPUERTORICO
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['germany_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['germany_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['zamunda_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['zamunda_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['usa_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['usa_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['china_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['china_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['spain_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['spain_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['russia_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['russia_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['argentina_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['argentina_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['belgium_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['belgium_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['france_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['france_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['greece_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['greece_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['croatia_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['croatia_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['italy_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['italy_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id'].fields.append(
  _TRAFFICSIGNELEMENT.fields_by_name['puerto_rico_element_id'])
_TRAFFICSIGNELEMENT.fields_by_name['puerto_rico_element_id'].containing_oneof = _TRAFFICSIGNELEMENT.oneofs_by_name['traffic_sign_element_id']
_TRAFFICSIGN.fields_by_name['traffic_sign_elements'].message_type = _TRAFFICSIGNELEMENT
_TRAFFICSIGN.fields_by_name['position'].message_type = util__pb2._POINT
DESCRIPTOR.message_types_by_name['TrafficSignIDGermanyEnum'] = _TRAFFICSIGNIDGERMANYENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDZamundaEnum'] = _TRAFFICSIGNIDZAMUNDAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDUsaEnum'] = _TRAFFICSIGNIDUSAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDChinaEnum'] = _TRAFFICSIGNIDCHINAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDSpainEnum'] = _TRAFFICSIGNIDSPAINENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDRussiaEnum'] = _TRAFFICSIGNIDRUSSIAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDArgentinaEnum'] = _TRAFFICSIGNIDARGENTINAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDBelgiumEnum'] = _TRAFFICSIGNIDBELGIUMENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDFranceEnum'] = _TRAFFICSIGNIDFRANCEENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDGreeceEnum'] = _TRAFFICSIGNIDGREECEENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDCroatiaEnum'] = _TRAFFICSIGNIDCROATIAENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDItalyEnum'] = _TRAFFICSIGNIDITALYENUM
DESCRIPTOR.message_types_by_name['TrafficSignIDPuertoRicoEnum'] = _TRAFFICSIGNIDPUERTORICOENUM
DESCRIPTOR.message_types_by_name['TrafficSignElement'] = _TRAFFICSIGNELEMENT
DESCRIPTOR.message_types_by_name['TrafficSign'] = _TRAFFICSIGN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrafficSignIDGermanyEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDGermanyEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDGERMANYENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDGermanyEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDGermanyEnum)

TrafficSignIDZamundaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDZamundaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDZAMUNDAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDZamundaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDZamundaEnum)

TrafficSignIDUsaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDUsaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDUSAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDUsaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDUsaEnum)

TrafficSignIDChinaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDChinaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDCHINAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDChinaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDChinaEnum)

TrafficSignIDSpainEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDSpainEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDSPAINENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDSpainEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDSpainEnum)

TrafficSignIDRussiaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDRussiaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDRUSSIAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDRussiaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDRussiaEnum)

TrafficSignIDArgentinaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDArgentinaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDARGENTINAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDArgentinaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDArgentinaEnum)

TrafficSignIDBelgiumEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDBelgiumEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDBELGIUMENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDBelgiumEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDBelgiumEnum)

TrafficSignIDFranceEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDFranceEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDFRANCEENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDFranceEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDFranceEnum)

TrafficSignIDGreeceEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDGreeceEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDGREECEENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDGreeceEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDGreeceEnum)

TrafficSignIDCroatiaEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDCroatiaEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDCROATIAENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDCroatiaEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDCroatiaEnum)

TrafficSignIDItalyEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDItalyEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDITALYENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDItalyEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDItalyEnum)

TrafficSignIDPuertoRicoEnum = _reflection.GeneratedProtocolMessageType('TrafficSignIDPuertoRicoEnum', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNIDPUERTORICOENUM,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignIDPuertoRicoEnum)
  })
_sym_db.RegisterMessage(TrafficSignIDPuertoRicoEnum)

TrafficSignElement = _reflection.GeneratedProtocolMessageType('TrafficSignElement', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGNELEMENT,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSignElement)
  })
_sym_db.RegisterMessage(TrafficSignElement)

TrafficSign = _reflection.GeneratedProtocolMessageType('TrafficSign', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICSIGN,
  '__module__' : 'traffic_sign_pb2'
  # @@protoc_insertion_point(class_scope:commonroad.TrafficSign)
  })
_sym_db.RegisterMessage(TrafficSign)


# @@protoc_insertion_point(module_scope)
